==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/DescribeVodSourceRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeVodSourceRequest(
    sourceLocationName: __string,
    vodSourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DescribeVodSourceRequest = {
    import DescribeVodSourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DescribeVodSourceRequest
      .builder()
      .sourceLocationName(__string.unwrap(sourceLocationName): java.lang.String)
      .vodSourceName(__string.unwrap(vodSourceName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.DescribeVodSourceRequest.ReadOnly =
    zio.aws.mediatailor.model.DescribeVodSourceRequest.wrap(buildAwsValue())
}
object DescribeVodSourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DescribeVodSourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DescribeVodSourceRequest =
      zio.aws.mediatailor.model
        .DescribeVodSourceRequest(sourceLocationName, vodSourceName)
    def sourceLocationName: __string
    def vodSourceName: __string
    def getSourceLocationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(sourceLocationName)
    def getVodSourceName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(vodSourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeVodSourceRequest
  ) extends zio.aws.mediatailor.model.DescribeVodSourceRequest.ReadOnly {
    override val sourceLocationName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.sourceLocationName())
    override val vodSourceName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.vodSourceName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeVodSourceRequest
  ): zio.aws.mediatailor.model.DescribeVodSourceRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mediatailor_3-5.17.225.2-sources.jar: zio/aws/mediatailor/model/DescribeVodSourceRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeVodSourceRequest(
    sourceLocationName: __string,
    vodSourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DescribeVodSourceRequest = {
    import DescribeVodSourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DescribeVodSourceRequest
      .builder()
      .sourceLocationName(sourceLocationName: java.lang.String)
      .vodSourceName(vodSourceName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.DescribeVodSourceRequest.ReadOnly =
    zio.aws.mediatailor.model.DescribeVodSourceRequest.wrap(buildAwsValue())
}
object DescribeVodSourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DescribeVodSourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DescribeVodSourceRequest =
      zio.aws.mediatailor.model
        .DescribeVodSourceRequest(sourceLocationName, vodSourceName)
    def sourceLocationName: __string
    def vodSourceName: __string
    def getSourceLocationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(sourceLocationName)
    def getVodSourceName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(vodSourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeVodSourceRequest
  ) extends zio.aws.mediatailor.model.DescribeVodSourceRequest.ReadOnly {
    override val sourceLocationName: __string =
      impl.sourceLocationName(): __string
    override val vodSourceName: __string = impl.vodSourceName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeVodSourceRequest
  ): zio.aws.mediatailor.model.DescribeVodSourceRequest.ReadOnly = new Wrapper(
    impl
  )
}
